@@ -2,14 +2,14 @@ from .utils import (treemap_path,
                     create_pairs,
                     column_use,
                     figures_to_html)
-from datamallet.tabular.utils import (check_dataframe,
+from datamallet.tabular.utils import (check_dataframe,extract_numeric_cols,
                                       calculate_correlation)
 import plotly.express as px
 
 
 def create_pie(df,
                numeric_cols,
-               pie_sector,
+               list_of_categorical_columns,
                create_html=False,
                hole=False,
                filename='pie'):
@@ -17,7 +17,7 @@ def create_pie(df,
     Creates a pie chart for every categorical variable in the dataset.
     :param df: pandas dataframe,
     :param numeric_cols: list of columns with numeric data
-    :param pie_sector:list,
+    :param list_of_categorical_columns:list of column names which have categorical data
     :param create_html:boolean, whether the figures should be converted to HTML or not
     :param hole:boolean, hole in the pie chart
     :param filename:str, a suitable name for the produced html file, exclude the extension
@@ -26,7 +26,7 @@ def create_pie(df,
     figure_list = list()
 
     for value in numeric_cols:
-        for name in pie_sector:
+        for name in list_of_categorical_columns:
             plot = px.pie(names=name,
                           data_frame=df,
                           values=value,
@@ -101,7 +101,8 @@ def create_box(df,
                notched=False,
                color=None,
                filename='box',
-               create_html=True
+               create_html=True,
+               hue_threshold=5
                ):
     """
     Creates a list of boxplot figure objects created for the entire dataset
@@ -117,12 +118,13 @@ def create_box(df,
     :param color:
     :param filename:
     :param create_html:boolean, whether to create an html file or not
+    :param hue_threshold: int,
     :return:
     """
     figure_list = list()
     numeric_cols = col_types['numeric']
 
-    column_use_dict = column_use(df, col_types=col_types, threshold=5)
+    column_use_dict = column_use(df, col_types=col_types, threshold=hue_threshold)
 
     hue_cols = column_use_dict['hue']
     if len(hue_cols) == 0:
@@ -219,19 +221,24 @@ def create_sunburst(df,
     return figure_list
 
 
-def create_correlation_plot(df, correlation_method='pearson'):
+def create_correlation_plot(df,
+                            correlation_method='pearson',
+                            create_html=False,
+                            filename='correlation_plot'):
     """
     Creates a correlation plot for the provided dataframe
     based on the correlation method supplied and returns a list of plotly graph objects
     :param df: pandas dataframe
     :param correlation_method: str, method for computing correlation, one of kendall, pearson, spearman
+    :param create_html: boolean, whether to create html file or not
+    :param filename:str, name of file, the extension is excluded
     :return: list of graph objects
     """
     figure_list = list()
     check = check_dataframe(df=df)
     available_method = correlation_method in ['pearson', 'kendall', 'spearman']
 
-    if check and available_method:
+    if check and available_method and len(extract_numeric_cols(df=df))>1:
 
         correlation = calculate_correlation(df=df, method=correlation_method)
 
@@ -240,6 +247,9 @@ def create_correlation_plot(df, correlation_method='pearson'):
 
         figure_list.append(plot)
 
+    if create_html:
+        figures_to_html(figs=figure_list, filename=filename)
+
     return figure_list
 
 
